import { ColorRepresentation, Matrix3, Matrix4, Texture, Vector2, Vector3, Vector4 } from 'three';
import { VaryingArrayNode } from '..';
import { ArrayNode } from './arrays';
import { ShaderNode } from './compiler';
import { BooleanNode, ConstantRgbNode, FloatNode, IntNode, Mat2Node, Mat3Node, Mat4Node, RgbaNode, Sampler2DNode, Vec2Node, Vec3Node, Vec4Node } from './types';
import { UniformBoolNode, UniformFloatNode, UniformMat2Node, UniformMat3Node, UniformMat4Node, UniformSampler2d, UniformVec2Node, UniformVec3Node, UniformVec4Node } from './uniforms';
import { VaryingMat2Node, VaryingMat3Node, VaryingMat4Node, VaryingVec2Node, VaryingVec3Node, VaryingVec4Node } from './varying';
export declare function uniformBool(name: string, value?: boolean): UniformBoolNode;
export declare function uniformFloat(name: string, value?: number): UniformFloatNode;
export declare function uniformVec2(name: string, value?: Vector2): UniformVec2Node;
export declare function uniformVec3(name: string, value?: Vector3): UniformVec3Node;
export declare function uniformVec4(name: string, value?: Vector4): UniformVec4Node;
export declare function uniformMat2(name: string, value?: any): UniformMat2Node;
export declare function uniformMat3(name: string, value?: Matrix3): UniformMat3Node;
export declare function uniformMat4(name: string, value?: Matrix4): UniformMat4Node;
export declare function uniformSampler2d(name: string): UniformSampler2d;
export declare function textureSampler2d(texture: Texture): UniformSampler2d;
export declare function varyingFloat(n: FloatNode): FloatNode;
export declare function varyingVec2(n: Vec2Node): VaryingVec2Node;
export declare function varyingVec3(n: Vec3Node): VaryingVec3Node;
export declare function varyingVec4(n: Vec4Node): VaryingVec4Node;
export declare function varyingMat2(n: Mat2Node): VaryingMat2Node;
export declare function varyingMat3(n: Mat3Node): VaryingMat3Node;
export declare function varyingMat4(n: Mat4Node): VaryingMat4Node;
export declare function varyingArray<T extends ShaderNode<string>>(node: ArrayNode<T>): VaryingArrayNode<T>;
export declare function neg(f: FloatNode): FloatNode;
export declare function negVec2(n: Vec2Node): Vec2Node;
export declare function negVec3(n: Vec3Node): Vec3Node;
export declare function negVec4(n: Vec4Node): Vec4Node;
export declare function rgba(color: ColorRepresentation | Vec4Node | Vec3Node, alpha?: number | FloatNode): RgbaNode;
export declare function rgb(color: ColorRepresentation): ConstantRgbNode;
export declare function bool(b: boolean): BooleanNode;
export declare function float(f: number | FloatNode): FloatNode;
export declare function int(i: number | IntNode): IntNode;
export declare function vec2(x: number | Vector2 | Vector3 | Vector4 | Vec3Node | Vec4Node, y?: number): Vec2Node;
export declare function vec3(x: number | Vector3 | Vector4 | Vec3Node | Vec4Node | FloatNode, y?: number | FloatNode, z?: number | FloatNode): Vec3Node;
export declare function vec4(x: number | Vector4 | Vec3Node, y: number | FloatNode, z?: number, w?: number): Vec4Node;
export declare function texture2d(sampler2d: Sampler2DNode, cord: Vec2Node, bias?: FloatNode): RgbaNode;
