import { UniformArrayNode } from './arrays';
import { StructType } from './structs';
import { FloatNode, Mat4Node, RgbNode, Sampler2DNode, Vec2Node, Vec3Node } from './types';
export declare abstract class PointLight extends StructType {
    static readonly typeName = "PointLight";
    readonly position: Vec3Node;
    readonly color: RgbNode;
    readonly distance: FloatNode;
    readonly decay: FloatNode;
}
export declare abstract class SpotLight extends StructType {
    static readonly typeName = "SpotLight";
    readonly position: Vec3Node;
    readonly direction: Vec3Node;
    readonly color: RgbNode;
    readonly distance: FloatNode;
    readonly decay: FloatNode;
    readonly coneCos: FloatNode;
    readonly penumbraCos: FloatNode;
}
export declare abstract class HemisphereLight extends StructType {
    static readonly typeName = "HemisphereLight";
    readonly direction: Vec3Node;
    readonly skyColor: RgbNode;
    readonly groundColor: RgbNode;
}
export declare abstract class DirectionalLight extends StructType {
    static readonly typeName = "DirectionalLight";
    readonly direction: Vec3Node;
    readonly color: RgbNode;
}
export declare abstract class PointLightShadow extends StructType {
    static readonly typeName = "PointLightShadow";
    readonly shadowBias: FloatNode;
    readonly shadowNormalBias: FloatNode;
    readonly shadowRadius: FloatNode;
    readonly shadowMapSize: Vec2Node;
    readonly shadowCameraNear: FloatNode;
    readonly shadowCameraFar: FloatNode;
}
export declare abstract class DirectionalLightShadow extends StructType {
    static readonly typeName = "DirectionalLightShadow";
    readonly shadowBias: FloatNode;
    readonly shadowNormalBias: FloatNode;
    readonly shadowRadius: FloatNode;
    readonly shadowMapSize: Vec2Node;
}
export declare abstract class SpotLightShadow extends StructType {
    static readonly typeName = "SpotLightShadow";
    readonly shadowBias: FloatNode;
    readonly shadowNormalBias: FloatNode;
    readonly shadowRadius: FloatNode;
    readonly shadowMapSize: Vec2Node;
}
export declare const lightProbe: UniformArrayNode<Vec3Node>;
export declare const uniformPointLights: UniformArrayNode<PointLight>;
export declare const uniformSpotLights: UniformArrayNode<SpotLight>;
export declare const uniformHemisphereLights: UniformArrayNode<HemisphereLight>;
export declare const uniformDirectionalLights: UniformArrayNode<DirectionalLight>;
export declare const uniformAmbient: import("./uniforms").UniformVec3Node;
export declare const uniformReceiveShadow: import("./uniforms").UniformBoolNode;
export declare const uniformPointLightShadows: UniformArrayNode<PointLightShadow>;
export declare const uniformPointShadowMap: UniformArrayNode<Sampler2DNode>;
export declare const uniformPointShadowMatrix: UniformArrayNode<Mat4Node>;
export declare const uniformDirectionalLightShadows: UniformArrayNode<DirectionalLightShadow>;
export declare const uniformDirectionalShadowMap: UniformArrayNode<Sampler2DNode>;
export declare const uniformDirectionalShadowMatrix: UniformArrayNode<Mat4Node>;
export declare const uniformSpotLightShadows: UniformArrayNode<SpotLightShadow>;
export declare const uniformSpotShadowMap: UniformArrayNode<Sampler2DNode>;
export declare const uniformSpotShadowMatrix: UniformArrayNode<Mat4Node>;
export declare const uniformCsmCascades: UniformArrayNode<Vec2Node>;
